// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
import { render, renderConfirmation } from "../ui/ui-root.js";
import { Shell, supportedShells as shells, setupZshDotfiles, setupBashPreExec } from "../utils/shell.js";
import { inferShell } from "../utils/shell.js";
import { loadConfig } from "../utils/config.js";
import log from "../utils/log.js";
import { loadAliases } from "../runtime/alias.js";
import { loadLocalSpecsSet } from "../runtime/runtime.js";
export const supportedShells = shells.join(", ");
export const action = (program) => async (options) => {
    const inISTerm = process.env.ISTERM === "1";
    if (options.check || inISTerm) {
        process.stdout.write(renderConfirmation(inISTerm));
        process.exit(0);
    }
    if (options.verbose)
        await log.enable();
    await loadConfig(program);
    await loadLocalSpecsSet();
    const shell = options.shell ?? (await inferShell());
    if (shell == null) {
        program.error(`Unable to identify shell, use the -s/--shell option to provide your shell`, { exitCode: 1 });
    }
    if (!shells.map((s) => s.valueOf()).includes(shell)) {
        program.error(`Unsupported shell: '${shell}', supported shells: ${supportedShells}`, { exitCode: 1 });
    }
    if (shell == Shell.Zsh) {
        await setupZshDotfiles();
    }
    else if (shell == Shell.Bash) {
        await setupBashPreExec();
    }
    await loadAliases(shell);
    await render(shell, options.test ?? false, options.login ?? false);
};
